<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'lebe_childtheme_locale_css' ) ):
	function lebe_childtheme_locale_css( $uri ) {
		if ( empty( $uri ) && is_rtl() && file_exists( get_template_directory() . '/rtl.css' ) ) {
			$uri = get_template_directory_uri() . '/rtl.css';
		}
		
		return $uri;
	}
endif;
add_filter( 'locale_stylesheet_uri', 'lebe_childtheme_locale_css' );

if ( ! function_exists( 'lebe_childtheme_css' ) ):
	function lebe_childtheme_css() {
		wp_enqueue_style( 'lebe_childtheme', trailingslashit( get_stylesheet_directory_uri() ) . 'style.css', array(
			'boostrap',
			'owl-carousel',
			'flat-icons',
			'scrollbar',
			'animation-on-scroll',
			'lebe-custom',
			'lebe-main-style',
			'lebe-main-style',
			'lebe_custom_css'
		) );
	}
endif;
add_action( 'wp_enqueue_scripts', 'lebe_childtheme_css', 20 );

/**
 * Override Lebe theme function
 * 
 * @param array  $img
 * @param string $class
 * @param string $alt
 * @param string $title
 *
 * @return string
 */
function lebe_img_output( $img, $class = '', $alt = '', $title = '' ) {
	
	$img_default = array(
		'width'  => '',
		'height' => '',
		'url'    => ''
	);
	$img         = wp_parse_args( $img, $img_default );
	$enable_lazy = lebe_get_option( 'lebe_enable_lazy', false );
    
    $alt = 'alfombras ' . $alt;
	
	if ( $enable_lazy ) {
		$img_lazy = lebe_img_lazy( $img['width'], $img['height'] );
		$img_html = '<img class="fami-img fami-lazy lazy ' . esc_attr( $class ) . '" width="' . esc_attr( $img['width'] ) . '" height="' . esc_attr( $img['height'] ) . '" src="' . $img_lazy . '" data-src="' . esc_url( $img['url'] ) . '" alt="' . esc_attr( $alt ) . '" title="' . esc_attr( $title ) . '" />';
	} else {
		$img_html = '<img class="fami-img ' . esc_attr( $class ) . '" width="' . esc_attr( $img['width'] ) . '" height="' . esc_attr( $img['height'] ) . '" src="' . esc_url( $img['url'] ) . '" alt="' . esc_attr( $alt ) . '" title="' . esc_attr( $title ) . '" />';
	}
	
	return $img_html;
}

//function tutien_change_attachement_image_attributes( $attr, $attachment ) {
//	// Get post parent
//	$parent = get_post_field( 'post_parent', $attachment );
//	
//	// Get post type to check if it's product
//	$type = get_post_field( 'post_type', $parent );
//	if ( $type != 'product' ) {
//		$title       = get_post_field( 'post_title', $parent );
//		$attr['alt'] = 'alfombra ' . $title;
//	}
//	
//	return $attr;
//}
//
//// add_filter( 'wp_get_attachment_image_attributes', 'tutien_change_attachement_image_attributes', 20, 2 );

function tutien_modify_shop_product_image( $image, $product, $size, $attr, $placeholder ) {
	if ( $product->get_image_id() ) {
        $title       = get_post_field( 'post_title', $product );
        $attr['alt'] = 'alfombras ' . $title;
		$image = wp_get_attachment_image( $product->get_image_id(), $size, false, $attr );
	} elseif ( $product->get_parent_id() ) {
		$parent_product = wc_get_product( $product->get_parent_id() );
		if ( $parent_product ) {
            $title       = get_post_field( 'post_title', $parent_product );
            $attr['alt'] = 'alfombras ' . $title;
			$image = $parent_product->get_image( $size, $attr, $placeholder );
		}
	}
	
	if ( ! $image && $placeholder ) {
		$image = wc_placeholder_img( $size );
	}
	
	return $image;
}

add_action( 'woocommerce_product_get_image', 'tutien_modify_shop_product_image', 10, 5 );


// DLVJ funciton to enqueue script
if ( ! function_exists( 'DLVJ_enqueue_scripts' ) ) {
	function DLVJ_enqueue_scripts() {
		wp_enqueue_script( 'custom-js', get_stylesheet_directory_uri() . '/js/custom.js', array('jquery'), false );
	}
}
add_action( 'wp_enqueue_scripts', 'DLVJ_enqueue_scripts', 30 );
add_filter( 'wpcf7_load_js', '__return_false' );
add_filter( 'wpcf7_load_css', '__return_false' );
function deregister_cf7_js() {
if ( !is_page(array( 'contacto', 'finalizar-compra-2', 'mi-cuenta' ) )) {
wp_deregister_script( 'contact-form-7');
}
}
add_action( 'wp_print_scripts', 'deregister_cf7_js' );
function deregister_ct7_styles() {
if ( !is_page(array( 'contacto', 'finalizar-compra-2', 'mi-cuenta' ) )) {
wp_deregister_style( 'contact-form-7');
}
}
add_action( 'wp_print_styles', 'deregister_ct7_styles');